package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut

__DATA__

M35J0``,````$````__\``+@`````````0```````````````````````````
M````````````````````^`````X?N@X`M`G-(;@!3,TA5&AI<R!P<F]G<F%M
M(&-A;FYO="!B92!R=6X@:6X@1$]3(&UO9&4N#0T*)``````````")82,1D3J
MWT9$ZM]&1.K?Q5CDWT1$ZM\I6^#?343JWRE;[M]$1.K?Q4RWWT)$ZM\]6.;?
M1$3JWT9$Z]\61.K?N63NWT5$ZM]P8N#?1$3JW_Y"[-]'1.K?4FEC:$9$ZM\`
M``````````````````````````````!010``3`$$`'BO:T<``````````.``
M#P$+`08``#````"@````````\#D````0````0`````!````0````$```!```
M```````$``````````#@````$```\><```,``````!```!``````$```$```
M`````!```````````````.2=``!D`````,```-`1````````````````````
M```````````````P00``'```````````````````````````````````````
M````````````````````0```)`$`````````````````````````````````
M`"YT97AT````+"L````0````,````!```````````````````"```&`N<F1A
M=&$``+YC````0````'````!```````````````````!```!`+F1A=&$```!D
M!````+`````0````L```````````````````0```P"YR<W)C````T!$```#`
M````(````,```````````````````$```,``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`&AP04``:`0Y0`!H5$%``.CJ*```4.C>*```@\00PS/`PU6+[('L"`0``%-6
M5VB804``Z*@!``")1?R-A?C[___'!"0`!```,]M04_\5"$!``(7`#X5,`0``
M_S40L$``BW4(5O\5A$!``%E9A<!6=!-HB$%``.CS`0``68O&6>E7`0``Z!XI
M``#_-12P0`"+/8Q`0`")1?C_=0S_UX/$#(OP._,/A!\!```X'G4%OH1!0``Y
M7?QT$U;_=?SHX"@``%F%P%D/A,L```!6Z-8H``"*5##_68L-$+!``#H1=0I(
MB!P&BE0&_^OLBU7X_W4(C400`3T`!```#XW-````45:-A?C[__]H?$%``%#_
M%91`0`#HYR<``%#H\R<``(LPZ-HG``!0Z.`G``"#Q!Q0C87X^___4.C$)P``
M4.C0)P``6?\P_U90@\0,A<!U2.BL)P``4.BR)P``9HM`!EEF)0#P9CT`@'4N
MZ)(G``!0Z)XG``"+,%F-A?C[__]J`5#H>R<``%#HAR<``%G_,/\6@\0,A<!T
M$/\U%+!``%/_UUE9Z?K^__^-A?C[__]0:(A!0`#HMP```(V%^/O__U#_%41`
M0`"#Q`SK$O]U"&B(04``Z)@```"+10A965]>6\G#58OLC44(4/]U".@$````
M65E=PU6+[%%35HMU"%>%]G1FBQV`0$``_].#.`!T68H.B\:$R70+@/D]=`:*
M2`%`Z_$KQHE%_/_3BS"+/H7_=#?_=?S_=0A7_Q5`0$``@\0,A<!U"8M%_(`\
M!SUT!8/&!.O8_],K,(M%#,'^`HDPBT7\C40'`>L",\!?7EO)PU6+[%%1BT4,
M@#@]=0/_10Q35E?_=0SH'B<``(M="(E%^(U%_%!3Z%K___^+-8!`0`"+^(/$
M#(7_=")7Z/DF```[1?A9#X++````BTT,B@&(!T=!A,!U]ND\`0``_]:+`#/_
M,\DY"'0&@\`$1^OV.0U$M$``=$#H%B8``%#H*"8``(L868T$O0@```!0_];_
M,.C\)0``4.@.)@``6?\P_U,$@\0,B]C_UHD8_]:#.`!U5>FQ````QP5$M$``
M`0```.C,)0``4.C>)0``BQA9C02]"````%#HMB4``%#HR"4``%G_,/\3B]A9
MA=M9='F+Q\'@`E#_UO\P4_\5?$!``(/$#/_6B1C_UHL`BUT(@V2X!`")??R*
M`XO[A,!T"CP]=`:*1P%'Z_+H924``%#H=R4``(L0BT7X*_M9B54(C40'`E#H
M2B4``%#H7"4``%G_,(M%"/\068OX6?_6BP"+3?R%_XD\B'4%@\C_ZR[_UHL`
MBTW\BP2(B@M#A,F("'0(@/D]=`-`Z^^+50S&`#U`B@J("$!"A,EU]C/`7UY;
MR<.+1"0$5HOPB\B*`(3`=!>+%1"P0`"*$CK"=0.-<0&*00%!A,!U\8O&7L-6
MBW0D"(7V=&^`/@!T:E;H7"4``(U$,/]9BPT0L$``.\9V%HH1.!!U!4@[QG?W
M.\9V"3@0=`-(Z_4[QG4)B@`Z`70U4>LW2#O&=@:*$#H1=/4KQHU(`H'Y``0`
M`'8$,\!>PT!05KX\L$``5O\5>$!``(/$#(O&7L-HA$%``/\51$!``%E>PU6+
M[(/L)%-65VH(6;YL0D``C7W<:%Q"0`#SI6:EZ`D!``#'!"100D``Z/T```"[
MF$%``%/H\@```+Y$0D``5NCG````OSA"0`!7Z-P```!H+$)``.C2````:(A!
M0`#HR````&@@0D``Z+X```!H%$)``.BT````:`!"0`#HHOS__X/$)(7`=`E0
M5^@B_?__65EH[$%``.B(_/__A<!9=`U0:.!!0`#H!OW__UE9:-!!0`#H;/S_
M_X7`670+4%/H[OS__UE9ZTYHO$%``.A2_/__A<!9=`105NOD:+1!0`#H!B0`
M`+^H04``C5P%Z%?H]R,``%!74_\5=$!``(/$%(7`=1)7Z.$C```#PU!6Z)_\
M__^#Q`QHI$%``&A<0D``Z(W\__]965]>6\G#58OL48U%_%#_=0CH^_O__UF%
MP%ET'O\5@$!``(L`BTW\C0R(BU$$C4$$A=*)$734B\CK\,G#H1BP0`"#^/]U
M)6A$0D``Z*[[__^%P%ET#XH`A,!T"3PP=`5J`5CK`C/`HQBP0`##58OL@^P@
MN,A"0`!7B_A0B47@QT7DP$)``,=%Z+!"0`#'1>RH0D``QT7PE$)``,=%])!"
M0`")??CH'",``(7`60^&Q````(U%X%-6B47\5^@^^___B_!9A?8/A(,```!6
MZ/0B``"%P%ET>/]U"%;_%81`0`!9A<!9=7/H,B(``%#H1"(``/\U%+!``(LX
MZ,<B``!6B]CHOR(``/]U"`/8Z+4B``"#Q!"-1`,"4.@`(@``4.@2(@``6?\P
M_Q=6B_C_-12P0`#_=0AH?$%``%?_%91`0`!7_W7XZ$/[__^#Q"3K"_]U"%?H
M-?O__UE9@T7\!(M%_(LX5XE]^.A:(@``A<!9#X=&____7EM?R<-5B^RXX(``
M`.A)(@``@V7T`%-6NY!"0`!HF$%``,=%V$Q#0`#'1=Q004``QT7@A$%``(E=
MY,=%P.!!0`#'1<1$0T``QT7(/$-``,=%S#1#0`#'1=`P0T``B5W4QT7H*$-`
M`,=%[!Q#0`")7?#H%/K__XOP687V=!]6Z,XA``"%P%ET%%;H:O[__U;_%41`
M0`!96>ER!0``O@`$``!7B77XZ/\@``!0Z!$A``"+.%E6Z/`@``!0Z`(A``!9
M_S#_%UE9C4WX45#_%0!`0`#H\_?__X7`B47X=3Z-?>B+-U;H:2$``(7`678?
M5NB7^?__A<!9=`M0_Q5$0$``68E%^(/'!(-]^`!TU(-]^`!U"<=%^!1#0`#K
M1(MU^(`^`'0\OP<!``"A9$!``(,X`7X/#[X&5U#_%6A`0`!96>L1BPUL0$``
M#[X&BPEFBP1!(\>%P'4#Q@9?1H`^`'7)C47`B47\BT7\BS!6Z.$@``"%P%D/
MAJ````!6Z`OY__^+\%F%]@^$@0```.@:(```4.@F(```BSCH#2```%#H$R``
M`%E94%;H_A\``%#H"B```%G_,/]74(/$#(7`=4WHYA\``%#H[!\``&:+0`99
M9B4`\&8]`$!U,^C,'P``4.C8'P``BSA9:@)6Z+L?``!0Z,<?``!9_S#_%X/$
M#(7`=0M6_Q5$0$``68E%](-%_`2#??0`#X1,____@WWT``^%J0```(U%V(E%
M_(M%_(LP5N@=(```A<!9#X:/````Z&<?``!0Z',?``"+..A:'P``4.A@'P``
M65E05NA+'P``4.A7'P``6?\P_U=0@\0,A<!U3>@S'P``4.@Y'P``9HM`!EEF
M)0#P9CT`0'4SZ!D?``!0Z"4?``"+.%EJ`E;H"!\``%#H%!\``%G_,/\7@\0,
MA<!U"U;_%41`0`!9B47T@T7\!(-]]``/A%W_____=?CH?1\``/]U](OXZ',?
M``"^#$-```/X5NAF'P``4P/XZ%X?``"-O`<`!```Z*H>``!0Z+P>``"+$(/$
M%(E5_%?HEAX``%#HJ!X``%G_,(M%_/\0_W7XB47\5HLUE$!``/\U$+!``/]U
M]&@`0T``4/_6_W7\_Q5P0$``:*A"0`#H./?__U#_%41`0`"+?0A0_S?H:/7_
M_X/$-(E%"(7`=06+!XE%".A0^___A<`/A2D"``#H)!X``%#H,!X``(LXQP0D
M`(```/]U".@-'@``4.@9'@``6?\P_U<\@\0,B44(A<`/A/,!``#H[AT``%#H
M^AT``%F+.&H":O]J[O]U".C7'0``4.CC'0``6?\P_U<PZ,8=``!0Z-(=``"+
M.(/$&(V%('___VH&4/]U".BJ'0``4.BV'0``6?\P_U=$@\00@+T@?___``^%
MM0```("](7___T,/A:@```"`O2)___]!#X6;````@+TC?___0P^%C@```("]
M)'___T@/A8$```"`O25___]%=7CH3!T``%#H6!T``%F+.&H":O]JQO]U".@U
M'0``4.A!'0``6?\P_U<PZ"0=``!0Z#`=``"+.(/$&(V%('___VHI4/]U".@(
M'0``4.@4'0``6?\P_U=$C84@?___4U#_-1"P0`#_=?QH\$)``/]U_/_6@\0H
MZ2(!``"-A2#___]0Z#8!``#HR!P``%#HU!P``%E9BSB-A2!___]H`(```%#_
M=0CHJAP``%#HMAP``%G_,/]71(/$$(7`?B10C84@?___4(V%(/___U#H'@$`
M`.A^'```4.B*'```@\00Z[/H;AP``%#H>AP``(LX6?]U".A='```4.AI'```
M6?\P_U<0C84@____4(U%K%#HNQ,``(U%@(/$$#/_B44(#[9$/:Q0:.A"0`#_
M=0C_UH-%"`*#Q`Q'@_\4?..-18!3@&6H`%#_-1"P0`#_=?QH\$)``.M!:*1!
M0`!H1$)``.A@]?__65E3Z.D;``!0Z`$<``"+..C<&P``4.CT&P``_S#_5VB#
MQ`Q0_S40L$``_W7\:-A"0`#_=?S_UH/$&/]U_&B804``Z!GU____=?SH\?C_
M_XM%_(/$#%]>6\G#BT0D!#/)QP`!(T5GQT`$B:O-[\=`"/[<NIC'0`QV5#(0
MQT`0\.'2PXE(%(E(&(E(7,-5B^Q3BUT05HMU"%>+3A2-!-D[P7,#_T88B484
MB\/!Z!T!1AB+1ER%P'0T:D!?*_@[^WX"B_N+1EQ7_W4,C40&'%#H`!P```%]
M#`%^7(/$#"O?@WY<0'5+5NA*````68/[0'PLB_O![P:+Q_?8P>`&`]AJ0(U&
M'/]U#%#HQQL``(-%#$!6Z!X```"#Q!!/=>)3C48<_W4,4.BJ&P``@\0,B5Y<
M7UY;7<-5B^R![%0!``"+10A35E>-4!R-M:S^___'10@0````BPJ#P@2+^8O9
M@><``/\`P>L0"_N+V8'C`/\``,'A$`O9P>\(P>,("_N)/H/&!/]-"'7-:D"-
ME;3^__]>BTHL,TH8,TKX,PJ#P@2+^0/)P>\?"_E.B7HT=>.+>`2+4`B+<`R+
M"(O?(]?WTR/>B_$+VHO1P>H;P>8%"]:+<!`#\P/6B[6L_O__C90RF7F"6HOW
MP>8>P>\""_>+^??7(W@(B77L(_&+V@O^B_+!ZQO!Y@4+WHNUL/[__P/W`]Z+
M<`R-O#.9>8):B_&+V8E]^,'F'L'K`@OSB]KWTR-=[(EU_"/R"]Z+M;3^__^)
M70B+W\'K&\'G!0O?BWT(`_>+^L'G'L'J`@/>BW`("_J+5?B-M#.9>8):BUWX
M]](C5?PCWXE]](O^"].+WL'O&\'C!0O[BYVX_O__`]H#^XM5[(V<%YEY@EJ+
M??B+UXE=",'B'L'O`@O7B_[WUR-]](E5^"/6"_J+T\'J&\'C!0O3BYV\_O__
M`]^+??P#TXV4.IEY@EJ+_L'G'L'N`@O^BW4(]]8C=?B)??`C?0B+VL'C!0OW
MB_K![QL+^XN=P/[__P/>BW7T`_N-G#>9>8):BWT(B_>)7?S!YA[![P(+]XOZ
M]]<C??")=0@C\@O^B_/![AO!XP4+\XN=Q/[__P/?BWWX`_.-M#Z9>8):B_K!
MYQ[!Z@(+^HM5_/?2(U4(B7WL(WW\B][!XP4+UXO^P>\;"_N+G<C^__\#VHM5
M\`/[C9P7F7F"6HM]_(O7B5WXP>(>P>\""]>+_O?7(WWLB57\(]8+^HO3P>H;
MP>,%"].+G<S^__\#WXM]"`/3BUWXC90ZF7F"6HO^P><>P>X""_Z+=?CWUB-U
M_"/?B7WTB_H+\XO:P>\;P>,%"_N+G=#^__\#WHMU[`/[C9PWF7F"6HM]^(OW
MB5T(P>8>P>\""_>+^O?7(WWTB77X(_(+_HOSP>X;P>,%"_.+G=3^__\#WXM]
M_`/SC;0^F7F"6HOZP><>P>H""_J+50CWTB-5^(E]\"-]"(O>P>,%"]>+_L'O
M&PO[BYW8_O__`]J+5?0#^XV<%YEY@EJ+?0B+UXE=_,'B'L'O`@O7B_[WUR-]
M\(E5""/6"_J+T\'J&\'C!0O3BYW<_O__`]^+??@#TXV4.IEY@EJ+_L'G'L'N
M`@O^BW7\]]8C=0B)?>PC??R+VL'C!0OWB_K![QL+^XN=X/[__P/>BW7P`_N-
MG#>9>8):BWW\B_>)7?C!YA[![P(+]XOZ]]<C?>R)=?PC\@O^B_/![AO!XP4+
M\XN=Y/[__P/?BWT(`_.+7?B-M#Z9>8):B_K!YQ[!Z@(+^HM5^/?2(U7\B7WT
M(]^+_@O3B][![QO!XP4+^XN=Z/[__P/:BU7L`_N-G!>9>8):BWWXB]>)70C!
MXA[![P(+UXO^]]<C??2)5?@CU@OZB]/!ZAO!XP4+TXN=[/[__P/?BWW\`].-
ME#J9>8):B_[!YQ[![@(+_HMU"/?6(W7XB7WP(WT(B]K!XP4+]XOZP>\;"_N+
MG?#^__\#WHMU]`/[C9PWF7F"6HM]"(OWB5W\P>8>P>\""_>+^O?7(WWPB74(
M(_(+_HOSP>X;P>,%"_.+G?3^__\#WXM]^`/SC;0^F7F"6HOZP><>P>H""_J+
M5?SWTB-5"(E]["-]_`O7B_[![QN+WL'C!0O[BYWX_O__`]J+5?`#^XV<%YEY
M@EJ+??R+UXE=^,'B'L'O`@O7B_O![QO!XP4+^XM=[(E5_#/:BY7\_O__,]X#
MUXO^`]J+50C!YQ[![@(+_HV4$Z'KV6Z)??2+\HOZBYT`____P>X;P><%"_>+
M??@S??P#WHMU[#-]]`/[C9PWH>O9;HM]^(OWB5T(P>8>P>\""_>+^\'O&\'C
M!8EU^`O[BYT$____,_(S=?0#WXM]_`/SC;0^H>O9;HOZP><>P>H""_J+UHO>
MB7WPP>H;P>,%"].+7?@SWXN]"/___S-="`/ZBU7T`]^-G!.AZ]ENBWT(B5W\
MB]?!XA[![P(+UXO[P>\;P>,%"_N+7?")50@SVHN5#/___S/>`]>+_@/:BU7X
MP><>P>X"C903H>O9;@O^B_*+VL'N&\'C!0OSBUT(B7WL,]^+O1#___\S7?P#
M_HMU\`/?BWW\C9PSH>O9;HOWP>8>P>\""_>+^XE=^(EU_,'O&\'C!0O[BUWL
M,]Z+M13___\SV@/WB_H#WHMU",'G'L'J`@OZC;0SH>O9;HE]](O6B_Z+G1C_
M___!ZAO!YP4+UXM]^#-]_`/:BU7L,WWT`_N-G!>AZ]ENBWWXB]>)70C!XA[!
M[P(+UXE5^(O[,]8S5?3![QO!XP4+^XN='/___P/?BWW\`].-E#JAZ]ENB_[!
MYQ[![@(+_HORB]J)??#![AO!XP4+\XM=^#/?B[T@____,UT(`_Z+=?0#WXM]
M"(V<,Z'KV6Z+]\'F'L'O`@OWB_N)7?R)=0C![QO!XP4+^XM=\#/>B[4D____
M,]H#]P/>BW7XB_K!YQ[!Z@*-M#.AZ]EN"_J+UHO>P>H;P>,%"].+70B)?>PS
MWXN]*/___S-=_`/ZBU7P`]^+??R-G!.AZ]ENB]?!XA[![P(+UXO[B5WXB57\
MP>\;P>,%"_N+7>PSVHN5+/___S/>`]>+_@/:BU4(P><>P>X""_Z-E!.AZ]EN
MB7WTB_*+^HN=,/___\'N&\'G!0OWBWWX,WW\`]Z+=>PS??0#^XV<-Z'KV6Z+
M??B+]XE=",'F'L'O`@OWB_O![QO!XP6)=?@+^XN=-/___S/R,W7T`]^+??P#
M\XVT/J'KV6Z+^L'G'L'J`@OZB]:+WHE]\,'J&\'C!0O3BUWX,]^+O3C___\S
M70@#^HM5]`/?BWT(C9P3H>O9;HO7P>(>P>\""]>+^XE=_(E5",'O&\'C!0O[
MBUWP,]J+E3S___\SW@/7`]J+5?B-O!.AZ]ENB];!XA[![@(+UHOWB]_![AO!
MXP4+\XM="(E5[#/:BY5`____,UW\`]:+=?P#VHM5\(V<$Z'KV6Z+UL'B'L'N
M`@O6B_.)7?B)5?S![AO!XP4+\XM=[#/:BY5$____,]\#UHOW`]J+50C!YA[!
M[P(+]XV4$Z'KV6Z)=?2+\HOZBYU(____P>X;P><%"_>+??@S??P#WHMU[#-]
M]`/[C;0WH>O9;HM]^(EU"(OWP>8>P>\""_>+^@M]](M="(EU^"/^B_(C=?3!
MXP4+_HMU",'N&POSBYU,____`]^+??P#\XVT/MR\&X^+^L'G'L'J`@OZB]>)
M??`+50@C5?@C?0B+W@O7B_[![QO!XP4+^XN=4/___P/:BU7T`_N-G!?<O!N/
MBWT(B]>)7?S!XA[![P(+UXOZB54("_XCUB-]\`OZB]/!ZAO!XP4+TXN=5/__
M_P/?BWWX`].-E#K<O!N/B_[!YQ[![@(+_HO:B_>)?>P+=?PC??S!XP4C=0@+
M]XOZP>\;"_N+G5C___\#WHMU\`/[C9PWW+P;CXM]_(OWB5WXP>8>P>\""_>+
M_HEU_`OZ(_(C?>P+_HOSP>X;P>,%"_.+G5S___\#WXM]"`/SC;0^W+P;CXOZ
MP><>P>H""_J+5?R)??2+7?P+UR-5^"/?B_X+TXO>P>\;P>,%"_N+G6#___\#
MVHM5[`/[C907W+P;CXM]^(E5"(O7P>(>P>\""]>+_@M]](M="(E5^"/ZB]8C
M5?3!XP4+^HM5",'J&PO3BYUD____`]^+??P#TXV4.MR\&X^+_L'G'L'N`@O^
MB]J+]XE]\`MU""-]",'C!2-U^`OWB_K![QL+^XN=:/___P/>BW7T`_N-G#?<
MO!N/BWT(B_>)7?S!YA[![P(+]XO^B74("_HC\B-]\`O^B_/![AO!XP4+\XN=
M;/___P/?BWWX`_.-M#[<O!N/B_K!YQ[!Z@(+^HO>B]>)?>P+5?PC??S!XP4C
M50@+UXO^P>\;"_N+G7#___\#VHM5\`/[C9P7W+P;CXM]_(O7B5WXP>(>P>\"
M"]>+^HE5_`O^(]8C?>P+^HO3P>H;P>,%"].+G73___\#WXM]"`/3BUW\C90Z
MW+P;CXO^P><>P>X""_Z+=?P+]R/?(W7XB7WTB_H+\XO:P>\;P>,%"_N+G7C_
M__\#WHMU[`/[C;0WW+P;CXM]^(EU"(OWP>8>P>\""_>+^@M]](M="(EU^"/^
MB_(C=?3!XP4+_HMU",'N&POSBYU\____`]\#\XM]_(VT/MR\&X^+^L'G'L'J
M`@OZB]Z+UXE]\`M5""-]",'C!2-5^`O7B_[![QL+^XM=@`/:BU7T`_N-G!?<
MO!N/BWT(B]>)7?S!XA[![P(+UXOZB54("_XCUB-]\`OZB]/!ZAO!XP4+TXM=
MA`/?BWWX`].-E#K<O!N/B_[!YQ[![@(+_HO:B_>)?>P+=?PC??S!XP4C=0@+
M]XOZP>\;"_N+78@#WHMU\`/[C9PWW+P;CXM]_(OWB5WXP>8>P>\""_>+_HEU
M_`OZ(_(C?>P+_HOSP>X;P>,%"_.+78P#WXM]"`/SBUW\C;0^W+P;CXOZP><>
MP>H""_J+5?P+UR/?(U7XB7WTB_X+TXO>P>\;P>,%"_N+79`#VHM5[`/[C907
MW+P;CXM]^(E5"(O7P>(>P>\""]>+_@M]](M="(E5^"/ZB]8C5?3!XP4+^HM5
M",'J&PO3BUV4`]^+??P#TXV4.MR\&X^+_L'G'L'N`@O^B]J+]XE]\`MU""-]
M",'C!2-U^`OWB_K![QL+^XM=F`/>BW7T`_N-G#?<O!N/BWT(B_>)7?S!YA[!
M[P(+]XO[P>\;P>,%"_N+7?`SWHEU"#/:BW6<`_>+^@/>BW7XP><>P>H"C;0S
MUL%BR@OZB]:+WL'J&\'C!0O3BUT(,]^)?>R+?:`S7?P#^HM5\`/?BWW\C9P3
MUL%BRHO7P>(>P>\""]>+^XE=^(E5_,'O&\'C!0O[BUWL,]J+5:0SW@/7B_X#
MVHM5",'G'L'N`@O^C903UL%BRHE]](ORB_J+7:C![AO!YP4+]XM]^#-]_`/>
MBW7L,WWT`_N-G#?6P6+*BWWXB_>)70C!YA[![P(+]XO[P>\;P>,%B77X"_N+
M7:PS\C-U]`/?BWW\`_.-M#[6P6+*B_K!YQ[!Z@(+^HO6B]Z)??#!ZAO!XP4+
MTXM=^#/?BWVP,UT(`_J+5?0#WXM]"(V<$];!8LJ+U\'B'L'O`@O7B_N)7?R)
M50C![QO!XP4+^XM=\#/:BU6T,]X#UP/:BU7XB_[!YQ[![@*-E!/6P6+*"_Z+
M\HO:P>X;P>,%"_.+70B)?>PSWXM]N#-=_`/^BW7P`]^+??R-G#/6P6+*B_?!
MYA[![P(+]XO[B5WXB77\P>\;P>,%"_N+7>PSWHMUO#/:`_>+^@/>BW4(P><>
MP>H""_J-M#/6P6+*B7WTB]:+_L'J&\'G!0O7BWWXBUW`,WW\`]J+5>PS??0#
M^XV<%];!8LJ+??B+UXE=",'B'L'O`@O7B_O![QO!XP6)5?@+^XM=Q#/6,U7T
M`]^+??P#TXV4.M;!8LJ+_L'G'L'N`@O^B_*+VHE]\,'N&\'C!0OSBUWX,]^+
M?<@S70@#_HMU]`/?BWT(C9PSUL%BRHOWP>8>P>\""_>+^XE=_(EU",'O&\'C
M!0O[BUWP,]Z+=<PSV@/W`]Z+=?B+^L'G'L'J`HVT,];!8LH+^HO6B][!ZAO!
MXP4+TXM="(E][#/?BWW0,UW\`_J+5?`#WXV<$];!8LJ+??R)7?B+U\'B'L'O
M`@O7B_O![QO!XP4+^XM=[(E5_#/:BU74,]X#UXO^`]J+50C!YQ[![@(+_HV4
M$];!8LJ)??2+\HOZBUW8P>X;P><%"_>+??@S??P#WHMU[#-]]`/[C9PWUL%B
MRHM]^(OWB5T(P>8>P>\""_>+^\'O&\'C!8EU^`O[BUW<,_(S=?0#WXM]_`/S
MC;0^UL%BRHOZP><>P>H""_J+UHO>B7WPP>H;P>,%"].+7?@SWXM]X#-="`/Z
MBU7T`]^+?0B-G!/6P6+*B]?!XA[![P(+UXE=_(E5"(O[P>\;P>,%"_N+7?`S
MVHM5Y#/>`]<#VHM5^(O^P><>P>X"C903UL%BRHM="`O^B_*)5?0SW\'N&\'B
M!0ORBU7\,]H#S@/9BTWP`UWHBW7TC8P+UL%BRHD(BT@$`\Z)2`2+RL'A'L'J
M`@O*BU4(`T@(B4@(BT@,`\]?B4@,BT@0`\I>B4@06\G#58OL4U:+=0R+1AB+
M7A2)10R+P\'H`X/@/\9$,!R`0(/X.'XJ:D!9*\B-1#`<46H`4.@X"0``5NB-
M[?__:CB-1AQJ`%#H)0D``(/$'.L5:CA9*\B-1#`<46H`4.@."0``@\0,BT4,
M5HO(B$97P>D8B$Y4B\C!Z1"(3E6+R(O#_W4(P>@8B$98B\/!Z!"(1EF+P\'I
M",'H"(A.5HA&6HA>6^@&````65E>6UW#5HMT)`Q6Z!/M__^+1"0,68L.P>D8
MB`B+#L'I$(A(`8L.P>D(B$@"B@Z(2`.+5@2-3@3!ZAB(4`2+$<'J$(A0!8L1
MP>H(B%`&B@F(2`>+5@B-3@C!ZAB(4`B+$<'J$(A0"8L1P>H(B%`*B@F(2`N+
M5@R-3@S!ZAB(4`R+$<'J$(A0#8L1P>H(B%`.B@F(2`^+5A"-3A!>P>H8B%`0
MBQ'!ZA"(4!&+$<'J"(A0$HH)B$@3PX'L)`$``%.+G"0L`0``5E>%VP^$,0(`
M`%/HLP<``(7`60^$(@(``%/HI`<``(OP@<8"`0``Z.\&``!0Z`$'``"+.%E9
M5NC?!@``4.CQ!@``6?\P_Q>+/91`0`"+\%-H:$-``%;_UXU$)"Q05O\52$!`
M`(/$'(/X_XE$)!0/A,<!``!5BRV$0$``C40D,&A004``4/_5687`68U$)#!0
M=0Y3:&!#0`!6_]>#Q!#K"VA<0T``5O_7@\0,NUA#0`!35O_5B_A9A?]9=!Y3
M5^CZ!@``687`670L:%1#0`!7Z.D&``!9A<!9=!OV1"0<$'1<@[PD/`$```!T
M4FH!5NC__O__65F-1"0<4/]T)!S_%4Q`0`!9A<!9#X43`0``C40D,&A004``
M4/_5687`68U$)#!0=5O_M"0\`0``:&!#0`!6_Q640$``@\00ZU*-1"0P4/\5
M$$!``(-D)!``BSU00$``B40D%%;_UX7`6726BT0D$/]$)!"#^`I]B8-\)!0`
M=`K_="04_Q4,0$``5NO8:%Q#0`!6_Q640$``@\0,4U;_U8OX687_670F4U?H
M&P8``%F%P%D/A$G___]H5$-``%?H!@8``%F%P%D/A#3____V1"0<$'0.@[PD
M/`$````/A17___^-1"0P4/\5$$!``(-D)!``BSU00$``B40D%%;_UX7`60^$
M^?[__XM$)!#_1"00@_@*#XWH_O__@WPD%`!T"O]T)!3_%0Q`0`!6Z]#_="08
M_Q540$``_[0D/`$``/\5H$!``%E975]>6X'$)`$``,-35HMT)`Q75N@!X/__
MB_A7Z,_?__]9B]A9Z-?A__^%P'0TA?9T,%;H4@4``(7`670E:`Q#0`!3_Q6$
M0$``63O#6743:@%6Z&+]__]J`%?H6OW__X/$$%]>6\-1@V0D``!35E?H;@0`
M`%#HP@0``&H!6X@8QP0D7$)``.@XW?__A<!9=`N`.#%U!H!X`0!T!>@`X/__
M:@I3:-1#0`#H-00``%#H@P0``(/$$(7`#X2B````BP`Y'3RT0`!5B_.+0""+
M>!!^8[T```0`C4;_:@!05^@`!```4.A(!```@\00A<!T18L`BT@((\T[S74&
MBP"+`.L3:@)J`%#HV`,``%#H&@0``(/$$%"A0+1``/\TL.AC!```687`674-
M_T0D$$8[-3RT0`!\HJ$\M$``78U(_SE,)`QU'3O#B_-^%U?HDP,``%#HSP,`
M`$99.S4\M$``67SI:@13:-!#0`#H=0,``%#HPP,``(OP@\00A?9T-8L&:,1#
M0`"+0"#_,.A5`P``4.B+`P``BP:#Q`R+0""+`/9`"4!T#E#H.0,``%#H:0,`
M`%E9:@13:,!#0`#H)`,``%#H<@,``(OP@\00A?9T<FB(04``Z.S;__^%P%ET
M`U#K2^@>VO__B_B%_W0YBP97BT`@_S#HZP(``%#H(0,``.C@`@``4.CR`@``
MBS"#Q!!7Z,\"``!0Z.$"``!9_S#_5@A96>L<H4"T0`#_,(L&BT`@_S#HK`(`
M`%#HX@(``(/$#.B>`@``4.CR`@``@"``Z)`"``!0Z+H"``"#(`!HF$%``.A>
MV___@\0,HSBP0`"%P'41_S5`M$``Z,+@__]9HSBP0`#H6P(``%#H?P(``(LP
MQP0D[0$``/\U.+!``.A!`@``4.AE`@``6?\P_Q:#Q`R%P%]>6W0E@_@1=""#
M^/]T&U"A0+1``/\U.+!``/\P:'!#0`#H+@(``(/$$%G#58OL45%6C44,5U"-
M10A0_Q6L0$``,_]7Z'X"``"#Q`R`.`!U2^AK`@``.\>C-+!``'4CZ,T!``!0
MZ.4!``"+,%EJ`>B]`0``4.C5`0``6?\P_U8(65G_-32P0`#H+@(``.B?`0``
M4.@=`@``68DX6>B0`0``4.@(`@``@`@"Z((!``!0Z/H!``"`"`&+10B#P`6)
M??R)1?A9WVWX6=P=^$-``-_@GG8+:.1#0`#H=P$``%F+10B-!(44````4.BZ
M`0``6:-`M$``BTT,:@&+"8D(H4"T0`#'0`3@0T``H4"T0`#'0`@81$``H4"T
M0`#'!3RT0``#````QT`,W$-``/\%/+1``%@Y10A^'HL-/+1``(M5#(LU0+1`
M``/(BQ2"0(E4COP[10A\XJ$\M$``BTT(`\&+#4"T0`!7B7R!_*$\M$``BTT(
M_S5`M$``C40(_U!HRCA``/\U-+!``.@5`0``B_"#Q!0[]W4._S4TL$``Z/L`
M``!9B_#_-32P0`#HYP```,<$)%!"0`#H5MG__X7`674DH3BP0``[QW44:)A!
M0`#H/MG__SO'6:,XL$``=`=0Z'?[__]9_S4TL$``Z*$```!9_Q780$``B\9?
M7LG#Z"\```!0Z"O7__]9N)!"0`!J`%!0:((T0`!H`$1``.@0````4.BF````
M@\08P_\E'$%``/\E&$%``/\E%$%``/\E$$%``/\E#$%``/\E"$%``/\E!$%`
M`/\E`$%``/\E_$!``/\E^$!``/\E]$!``/\E\$!``/\E[$!``/\EZ$!``/\E
MY$!``/\EX$!``/\EW$!``/\EU$!``/\ET$!``/\ES$!``/\ER$!``/\EQ$!`
M`/\EP$!``/\EO$!``/\EN$!``/\EM$!``/\EL$!``/\EJ$!``/\ED$!``/\E
MB$!``,S,S,Q1/0`0``"-3"0(<A2!Z0`0```M`!```(4!/0`0``!S["O(B\2%
M`8OABPB+0`10P\S_)6!`0`#_)5Q`0`#,S,S,58OL:O]HV)U``&@@.T``9*$`
M````4&2))0````"#["!35E>)9>B#9?P`:@'_%5A`0`!9@PU8M$``_X,-7+1`
M`/__%1A`0`"+#52T0`")"/\5'$!``(L-4+1``(D(H2!`0`"+`*-@M$``Z,``
M``"#/3"P0```=0QH'A!``/\5)$!``%GHE````&@,L$``:`BP0`#H?P```*%,
MM$``B478C4784/\U2+1``(U%X%"-1=10C47D4/\5+$!``&@$L$``:`"P0`#H
M3````/\5,$!``(M-X(D(_W7@_W74_W7DZ";\__^#Q#")1=Q0_Q4T0$``BT7L
MBPB+"8E-T%!1Z`\```!96<.+9>C_==#_%3Q`0`#_)3A`0`#_)2A`0`!H```#
M`&@```$`Z`L```!96</#S/\EF$!``/\EG$!`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````-ZA````````F*$``*ZA``"\H0```````'RC``!LHP``7*,``$BC```\
MHP``+*,``!RC```4HP``!J,``/ZB``#FH@``W*(``,ZB``#"H@``N*(``*JB
M``"*HP``EJ(``(RB``!\H@``<*(``&:B``!<H@``4J(``$BB```^H@``+J(`
M`"2B```:H@``$*(```:B``#\H0``G*,``+"C``"@H@```````'BA``!FH0``
M4*$``$*A```PH0``$*$``/B@``#BH```U*```,B@``"XH```K*```)J@``"&
MH```=*```&2@``!0H```0*```#"@```BH```#J```/Z?``#FGP``U)\``,2?
M``"TGP``H)\``(Z?``!ZGP``;)\`````````````````````````````>*]K
M1P`````"````/0``````````X```.P```%P```!$>6YA3&]A9&5R.CIB;V]T
M7T1Y;F%,;V%D97(`<&5R;'AS:2YC````)7,E<R5S```N````4$%27U!23T=.
M04U%`````%!!4E]414U0`````#$```!005)?0TQ%04X]``!#3$5!3@```%!!
M4E]'3$]"04Q?0TQ%04X`````4$%27T=,3T)!3%]414U0`%!!4E]435!$25(`
M`%!!4E]'3$]"04Q?5$U01$E2````4$%27T=,3T)!3%]$14)51P````!005)?
M05)'5E\P``!005)?05)'0P````!005)?0T%#2$4```!005)?1$5"54<```!0
M05)?0TQ%04X```!005)?4U!!5TY%1`!005)?24Y)5$E!3$E:140`7U]%3E9?
M4$%27T-,14%.7U\@("`@("`@("`@("`@("```````````$193$1?3$E"4D%2
M65]0051(````4$%42`````!,24)205)97U!!5$@`````3$E"4$%42`!,1%],
M24)205)97U!!5$@`)7,E<W1E;7`M)74E<P```"4P,G@`````)7,E<V-A8VAE
M+25S)7,``"5S)7,E<R5S`````'!A<BT`````4UE35$5-``!54T523D%-10``
M``!54T52`````%1-4`!414U0`````%1%35!$25(`5$U01$E2``!#.EQ414U0
M`%PN+@!<+@``)7,``"5S7"5S````)7-<*BXJ```E<SH@8W)E871I;VX@;V8@
M<')I=F%T92!T96UP;W)A<GD@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`M(&%B
M;W)T:6YG('=I=&@@)6DN"@```#````!P97)L+F5X90`````8````05)'5@``
M```M+0``+64``'!A;FEC.B!M96UO<GD@=W)A<`````"`____ST%);G1E<FYA
M;',Z.E!!4CHZ0D]/5``````C(2]U<W(O8FEN+W!E<FP*"F5V86P@)V5X96,@
M+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PH@("`@:68@,#L@(R!N
M;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"@IP86-K86=E(%]?<&%R7W!L
M.PH*(R`M+2T@5&AI<R!S8W)I<'0@;75S="!N;W0@=7-E(&%N>2!M;V1U;&5S
M(&%T(&-O;7!I;&4@=&EM92`M+2T*(R!U<V4@<W1R:6-T.PH*(VQI;F4@,34Y
M"@IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@
M:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@<F5Q=6ER92!&:6QE.CI496UP
M.PH@("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(')E<75I<F4@1FEL
M93HZ4W!E8SL*("`@(&UY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER
M;F%M92@D<&%R7W1E;7`I.PH@("`@;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I
M;B`B)'!A<E]T96UP(GTI.PH@("`@1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U
M8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["B`@
M("!R;61I<B`D<&%R7W1E;7`["B`@("!R;61I<B`D=&]P9&ER.PH*("`@(&EF
M("@M9"`D<&%R7W1E;7`I('L*("`@("`@("`C(%-O;65T:&EN9R!W96YT('=R
M;VYG('5N;&EN:VEN9R!T:&4@=&5M<&]R87)Y(&1I<F5C=&]R>2X@(%1H:7,*
M("`@("`@("`C('1Y<&EC86QL>2!H87!P96YS(&]N('!L871F;W)M<R!T:&%T
M(&1I<V%L;&]W('5N;&EN:VEN9R!S:&%R960*("`@("`@("`C(&QI8G)A<FEE
M<R!A;F0@97AE8W5T86)L97,@=&AA="!A<F4@:6X@=7-E+B!5;FQI;FL@=VET
M:"!A(&)A8VMG<F]U;F0*("`@("`@("`C('-H96QL(&-O;6UA;F0@<V\@=&AE
M(&9I;&5S(&%R92!N;R!L;VYG97(@:6X@=7-E(&)Y('1H:7,@<')O8V5S<RX*
M"B`@("`@("`@;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`H@("`@("`@("`@
M("!414U03$%412`]/B`G=&UP6%A86%@G+`H@("`@("`@("`@("!$25(@/3X@
M1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"B`@("`@("`@("`@
M(%-51D9)6"`]/B`G+F-M9"<L"B`@("`@("`@("`@(%5.3$E.2R`]/B`P+`H@
M("`@("`@("D["@H@("`@("`@(",@0F5C875S92!T:&4@<&%R7W1E;7`@9&ER
M96-T;W)Y(&ES(&=O:6YG('1O(&)E(&1E;&5T960@:6X@80H@("`@("`@(",@
M8F%C:V=R;W5N9"!P<F]C97-S+"!T:&4@<&%R96YT('!R;V-E<W,@:60@;6%Y
M(&)E(')E=7-E9"!B969O<F4@=&AE"B`@("`@("`@(R!B86-K9W)O=6YD('!R
M;V-E<W,@8V]M<&QE=&5S+B`@5&\@96YS=7)E('1H870@=&AE('1E;7!O<F%R
M>0H@("`@("`@(",@9&ER96-T;W)Y(&1O97,@;F]T(&=E="!R975S960@=VAI
M;&4@:70@:7,@8F5I;F<@9&5L971E9"P@=')Y('1O"B`@("`@("`@(R!R96YA
M;64@:70@=&\@82!N86UE('1H870@:7,@<F5L871E9"!T;R!T:&4@=&5M<&]R
M87)Y('-C<FEP="!F:6QE+@H*("`@("`@("!M>2`D=&UP;F%M92`]("A&:6QE
M.CI3<&5C+3YS<&QI='!A=&@H)'1M<"T^9FEL96YA;64I*5LR73L@(R!F:6QE
M;F%M90H@("`@("`@("1T;7!N86UE(#U^(',O7"Y;7BY=*B0O+F1I<B\["B`@
M("`@("`@;7D@)&YE=T1I<B`]($9I;&4Z.E-P96,M/F-A='!A=&@H"B`@("`@
M("`@("`@("A&:6QE.CI3<&5C+3YS<&QI='!A=&@H)'!A<E]T96UP*2E;,"XN
M,5TL("1T;7!N86UE*3L*("`@("`@("!I9B`H<F5N86UE("1P87)?=&5M<"P@
M)&YE=T1I<BD@>PH@("`@("`@("`@("!O=71S*")296YA;65D("1P87)?=&5M
M<"!T;R`D;F5W1&ER(BD["B`@("`@("`@("`@("1P87)?=&5M<"`]("1N97=$
M:7(["B`@("`@("`@?0H*("`@("`@("!I9B`H)%Y/(#U^(&TO=VEN,S(O:2D@
M>PH@("`@("`@("`@("!P<FEN="`D=&UP("(*.FQO;W`*<FUD:7(@+W$@+W,@
M7"(D<&%R7W1E;7!<(@II9B!E>&ES="!<(B1P87)?=&5M<%PB(&=O=&\@;&]O
M<`IR;61I<B!<(B1T;W!D:7)<(@IR;2!<(B(@+B`D=&UP+3YF:6QE;F%M92`N
M(")<(@HB.PH@("`@("`@("`@("!C;&]S92`D=&UP.PH@("`@("`@("`@("!M
M>2`D<')O8SL*("`@("`@("`@("`@5VEN,S(Z.E!R;V-E<W,Z.D-R96%T92@*
M("`@("`@("`@("`@("`@("1P<F]C+"`D14Y6>T-/35-014-]+`H@("`@("`@
M("`@("`@("`@(B1%3E9[0T]-4U!%0WT@+V,@7"(B("X@)'1M<"T^9FEL96YA
M;64@+B`B7"(@/FYU;"`R/FYU;"`B+`H@("`@("`@("`@("`@("`@,2P@3D]2
M34%,7U!224]225197T-,05-3+"`B+B(*("`@("`@("`@("`@*3L*("`@("`@
M("!](&5L<V4@>PH@("`@("`@("`@("!P<FEN="`D=&UP("(C(2]B:6XO<V@*
M=VAI;&4@6R`M9"`G)'!A<E]T96UP)R!=.R!D;PH@("!R;2`M<F8@)R1P87)?
M=&5M<"<*9&]N90IR;61I<B`G)'1O<&1I<B<*<FT@)R(@+B`D=&UP+3YF:6QE
M;F%M92`N("(G"B(["B`@("`@("`@("`@(&-H;6]D(#`W,#`L)'1M<"T^9FEL
M96YA;64["B`@("`@("`@("`@(&UY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N
M("<@/B]D978O;G5L;"`R/B8Q("8G.PH@("`@("`@("`@("!C;&]S92`D=&UP
M.PH@("`@("`@("`@("!S>7-T96TH)&-M9"D["B`@("`@("`@?0H@("`@("`@
M(&]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R
M;2!C;&5A;G5P*2D["B`@("!]"GT@?0H*0D5'24X@>PH@("`@26YT97)N86QS
M.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/
M5#L*"B`@("!E=F%L('L*"E]P87)?:6YI=%]E;G8H*3L*"FEF("AE>&ES=',@
M)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*("`@
M($!!4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[
M4$%27T%21T-]("T@,2D["B`@("`D,"`]("1%3E9[4$%27T%21U9?,'T["GT*
M96QS92!["B`@("!F;W(@*&ME>7,@)45.5BD@>PH@("`@("`@(&1E;&5T92`D
M14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["B`@("!]"GT*"FUY("1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["@HC(&9I>"`D<')O9VYA;64@:68@:6YV;VME
M9"!F<F]M(%!!5$@*;7D@)4-O;F9I9R`]("@*("`@('!A=&A?<V5P("`@(#T^
M("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`H@("`@7V5X92`@("`@
M("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE
M)R`Z("<G*2P*("`@(%]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/
M4S(O(#\@)UQ<)R`Z("<O)RDL"BD["@I?<V5T7W!R;V=N86UE*"D["E]S971?
M<&%R7W1E;7`H*3L*"B,@36%G:6,@<W1R:6YG(&-H96-K:6YG(&%N9"!E>'1R
M86-T:6YG(&)U;F1L960@;6]D=6QE<R![>WL*;7D@*"1S=&%R=%]P;W,L("1D
M871A7W!O<RD["GL*("`@(&QO8V%L("1324=[7U]705).7U]](#T@<W5B('M]
M.PH*("`@(",@0VAE8VL@9FEL92!T>7!E+"!G970@<W1A<G0@;V8@9&%T82!S
M96-T:6]N('M[>PH@("`@;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA
M<W0["B`@("!B:6YM;V1E*%]&2"D["@H@("`@;7D@)&)U9CL*("`@('-E96L@
M7T9(+"`M."P@,CL*("`@(')E860@7T9(+"`D8G5F+"`X.PH@("`@;&%S="!U
M;FQE<W,@)&)U9B!E<2`B7&Y005(N<&U<;B(["@H@("`@<V5E:R!?1D@L("TQ
M,BP@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@<V5E:R!?1D@L("TQ
M,B`M('5N<&%C:R@B3B(L("1B=68I+"`R.PH@("`@<F5A9"!?1D@L("1B=68L
M(#0["@H@("`@)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["B`@("`C('U]
M?0H*("`@(",@17AT<F%C=&EN9R!E86-H(&9I;&4@:6YT;R!M96UO<GD@>WM[
M"B`@("!M>2`E<F5Q=6ER95]L:7-T.PH@("`@=VAI;&4@*"1B=68@97$@(D9)
M3$4B*2!["B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A
M9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!M>2`D
M9G5L;&YA;64@/2`D8G5F.PH@("`@("`@(&]U=',H<7$H56YP86-K:6YG(&9I
M;&4@(B1F=6QL;F%M92(N+BXI*3L*("`@("`@("!M>2`D8W)C(#T@*"`D9G5L
M;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PH@
M("`@("`@(&UY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN
M*B\I/R@N*BDH7"XN*BE\*3L*"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0[
M"B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*
M("`@("`@("!I9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP
M;7QP;'QI>'QA;"DD+VDI('L*("`@("`@("`@("`@;7D@*"1O=70L("1F:6QE
M;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD["B`@("`@("`@("`@(&EF
M("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@
M("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("`@("`@
M8VQO<V4@)&]U=#L*("`@("`@("`@("`@("`@(&-H;6]D(#`W-34L("1F:6QE
M;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B`@("`@("`@("`@
M("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M
M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>
M+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PH@("`@
M("`@("`@("`C('-H;W5L9"!B92!M;W9E9"!T;R!?=&5M<&9I;&4H*0H@("`@
M("`@("`@("!M>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A<V5N
M86UE)&5X="(["B`@("`@("`@("`@(&]U=',H(E-(3$E".B`D9FEL96YA;65<
M;B(I.PH@("`@("`@("`@("!O<&5N(&UY("1O=70L("<^)RP@)&9I;&5N86UE
M(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@
M("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("!C;&]S92`D;W5T
M.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)')E<75I
M<F5?;&ES='LD9G5L;&YA;65](#T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ
M.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["B`@("`@("`@("`@("`@("!B
M=68@/3X@)&)U9BP*("`@("`@("`@("`@("`@(&-R8R`]/B`D8W)C+`H@("`@
M("`@("`@("`@("`@;F%M92`]/B`D9G5L;&YA;64L"B`@("`@("`@("`@('T[
M"B`@("`@("`@?0H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@?0H@
M("`@(R!]?7T*"B`@("!L;V-A;"!`24Y#(#T@*'-U8B!["B`@("`@("`@;7D@
M*"1S96QF+"`D;6]D=6QE*2`]($!?.PH*("`@("`@("!R971U<FX@:68@<F5F
M("1M;V1U;&4@;W(@(21M;V1U;&4["@H@("`@("`@(&UY("1F:6QE;F%M92`]
M(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*("`@("`@
M("`@("`@;7D@)&ME>3L*("`@("`@("`@("`@9F]R96%C:"`H:V5Y<R`E<F5Q
M=6ER95]L:7-T*2!["B`@("`@("`@("`@("`@("!N97AT('5N;&5S<R`O7%$D
M;6]D=6QE7$4D+SL*("`@("`@("`@("`@("`@("1K97D@/2`D7SL@;&%S=#L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES
M='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PH@("`@("`@('T@;W(@<F5T=7)N
M.PH*("`@("`@("`D24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE
M+R1M;V1U;&4B.PH*("`@("`@("!I9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D
M969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PH@("`@("`@("`@("!M>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PH@("`@("`@("`@
M("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@('!R:6YT("1F:"`D9FEL96YA
M;64M/GMB=69].PH@("`@("`@("`@("!S965K*"1F:"P@,"P@,"D["B`@("`@
M("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@
M("`@("`@("`@("!M>2`H)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG
M+"`D9FEL96YA;64M/GMC<F-]*3L*("`@("`@("`@("`@:68@*"1O=70I('L*
M("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@
M("!P<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@("`@
M("!C;&]S92`D;W5T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&]P96X@
M;7D@)&9H+"`G/"<L("1N86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN
M;6]D92@D9F@I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*
M"B`@("`@("`@9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I
M;F0@)&UO9'5L92%<;B(["B`@("!]+"!`24Y#*3L*"B`@("`C($YO=R!L;V%D
M(&%L;"!B=6YD;&5D(&9I;&5S('M[>PH*("`@(",@:6YI=&EA;&EZ92!S:&%R
M960@;V)J96-T('!R;V-E<W-I;F<*("`@(')E<75I<F4@6%-,;V%D97(["B`@
M("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E($-A<G`Z.DAE879Y
M.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H@("`@(R!N;W<@;&5T)W,@=')Y(&=E
M='1I;F<@:&5L<&5R(&UO9'5L97,@9G)O;2!W:71H:6X*("`@(')E<75I<F4@
M24\Z.D9I;&4["@H@("`@(R!L;V%D(')E<W0@;V8@=&AE(&=R;W5P(&EN"B`@
M("!W:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L
M:7-T*5LP72D@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?
M1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@=6YL97-S("@D
M24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["B`@
M("`@("`@("`@(",@<F5Q=6ER92!M;V1U;&5S+"!D;R!O=&AE<B!E>&5C=71A
M8FQE(&9I;&5S"B`@("`@("`@("`@(&EF("@D9FEL96YA;64@/7X@+UPN<&UC
M/R0O:2D@>PH@("`@("`@("`@("`@("`@<F5Q=6ER92`D9FEL96YA;64["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@
M("`C(%-K:7`@06-T:79E4W1A=&4G<R!S:71E8W5S=&]M:7IE+G!L(&9I;&4Z
M"B`@("`@("`@("`@("`@("!D;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M
M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65]
M.PH@("`@?0H*("`@(",@?7U]"@H@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B
M4$M<,#`S7#`P-"(["B`@("`D<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[
M"GT*(R!]?7T*"B,@07)G=6UE;G0@<')O8V5S<VEN9R![>WL*;7D@0'!A<E]A
M<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D[
M"@HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["@HC($1O;B=T
M('-W86QL;W<@87)G=6UE;G1S(&9O<B!C;VUP:6QE9"!E>&5C=71A8FQE<R!W
M:71H;W5T("TM<&%R+6]P=&EO;G,*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'
M5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["B`@("!M>2`E
M9&ES=%]C;60@/2!Q=R@*("`@("`@("!P("`@8FQI8E]T;U]P87(*("`@("`@
M("!I("`@:6YS=&%L;%]P87(*("`@("`@("!U("`@=6YI;G-T86QL7W!A<@H@
M("`@("`@(',@("!S:6=N7W!A<@H@("`@("`@('8@("!V97)I9GE?<&%R"B`@
M("`I.PH@("`@=VAI;&4@*$!!4D=6*2!["B`@("`@("`@)$%21U9;,%T@/7X@
M+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*"B`@("`@("`@
M:68@*"0Q(&5Q("=))RD@>PH@("`@("`@("`@("!U;G-H:69T($!)3D,L("0R
M.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)TTG*2!["B`@("`@
M("`@("`@(&5V86P@(G5S92`D,B(["B`@("`@("`@?0H@("`@("`@(&5L<VEF
M("@D,2!E<2`G02<I('L*("`@("`@("`@("`@=6YS:&EF="!`<&%R7V%R9W,L
M("0R.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)T\G*2!["B`@
M("`@("`@("`@("1O=70@/2`D,CL*("`@("`@("!]"B`@("`@("`@96QS:68@
M*"0Q(&5Q("=B)RD@>PH@("`@("`@("`@("`D8G5N9&QE(#T@)W-I=&4G.PH@
M("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)T(G*2!["B`@("`@("`@
M("`@("1B=6YD;&4@/2`G86QL)SL*("`@("`@("!]"B`@("`@("`@96QS:68@
M*"0Q(&5Q("=Q)RD@>PH@("`@("`@("`@("`D<75I970@/2`Q.PH@("`@("`@
M('T*("`@("`@("!E;'-I9B`H)#$@97$@)TPG*2!["B`@("`@("`@("`@(&]P
M96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@
M;&]G.B`D(2(["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G5"<I
M('L*("`@("`@("`@("`@)&-A8VAE7VYA;64@/2`D,CL*("`@("`@("!]"@H@
M("`@("`@('-H:69T*$!!4D=6*3L*"B`@("`@("`@:68@*&UY("1C;60@/2`D
M9&ES=%]C;61[)#%]*2!["B`@("`@("`@("`@(&1E;&5T92`D14Y6>R=005)?
M5$5-4"=].PH@("`@("`@("`@("!I;FET7VEN8R@I.PH@("`@("`@("`@("!R
M97%U:7)E(%!!4CHZ1&ES=#L*("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH*2!U;FQE<W,@0$%21U8["B`@("`@("`@("`@("9[(E!!4CHZ1&ES
M=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["B`@("`@("`@("`@(&5X:70["B`@
M("`@("`@?0H@("`@?0I]"@HC(%A86"`M+2!A9&0@+2UP87(M9&5B=6<@<W5P
M<&]R="$*"B,@?7U]"@HC($]U='!U="!M;V1E("@M3RD@:&%N9&QI;F<@>WM[
M"FEF("@D;W5T*2!["B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP
M;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!R
M97%U:7)E($E/.CI&:6QE.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP
M.PH@("`@?0H*"B`@("!M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PH@("`@;7D@
M)'II<#L*"@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P96X@
M;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z
M("0A(CL*("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@8FQE<W,H)&9H
M+"`G24\Z.D9I;&4G*3L*"B`@("`@("`@)'II<"`]($%R8VAI=F4Z.EII<"T^
M;F5W.PH@("`@("`@("@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*("`@("`@("`@("`@
M;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PH@("`@?0H*"B`@("!M
M>2`E96YV(#T@9&\@>PH@("`@("`@(&EF("@D>FEP(&%N9"!M>2`D;65T82`]
M("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B`@("`@("`@("`@("1M
M971A(#U^(',O+BI><&%R.B0O+VUS.PH@("`@("`@("`@("`D;65T82`]?B!S
M+UY<4RXJ+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@+UX@("A;7CI=*RDZ
M("@N*RDD+VUG.PH@("`@("`@('T*("`@('T["@H@("`@(R!/<&5N(&EN<'5T
M(&%N9"!O=71P=70@9FEL97,@>WM["B`@("!L;V-A;"`D+R`](%PT.PH*("`@
M(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N(%!!4BP@)SPG+"`D
M<&%R(&]R(&1I92`B)"$Z("1P87(B.PH@("`@("`@(&)I;FUO9&4H4$%2*3L*
M("`@("`@("!D:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\
M4$%2/B!E<2`B4$M<,#`S7#`P-"(["B`@("!]"@H@("`@0W)E871E4&%T:"@D
M;W5T*2`["B`@("`*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<H"B`@("`@
M("`@)&]U="P*("`@("`@("!)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I
M;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`H@("`@("`@
M(#`W-S<L"B`@("`I(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*"B`@
M("`D+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD
M968["B`@("!S965K(%]&2"P@,"P@,#L*("`@(&UY("1L;V%D97(@/2!S8V%L
M87(@/%]&2#X["B`@("!I9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO
M861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*("`@("`@("!R97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@("`@("!005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0H@("`@?0H@("`@9F]R
M96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PH@("`@("`@(&UY("1V
M86P@/2`D96YV>R1K97E](&]R(&YE>'0["B`@("`@("`@)'9A;"`](&5V86P@
M)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["B`@("`@("`@;7D@)&UA9VEC(#T@
M(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PH@("`@("`@(&UY("1S
M970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B`@("`@("`@)&QO
M861E<B`]?B!S>R1M86=I8R@@*RE]>PH@("`@("`@("`@("`D;6%G:6,@+B`D
M<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*("`@
M("`@("!]96<["B`@("!]"B`@("`D9F@M/G!R:6YT*"1L;V%D97(I.PH@("`@
M)"\@/2!U;F1E9CL*("`@(",@?7U]"@H@("`@(R!7<FET92!B=6YD;&5D(&UO
M9'5L97,@>WM["B`@("!I9B`H)&)U;F1L92D@>PH@("`@("`@(')E<75I<F4@
M4$%2.CI(96%V>3L*("`@("`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["B`@("`@("`@:6YI=%]I;F,H*3L*("`@("`@("!R97%U:7)E7VUO
M9'5L97,H*3L*"B`@("`@("`@;7D@0&EN8R`]('-O<G0@>PH@("`@("`@("`@
M("!L96YG=&@H)&(I(#P]/B!L96YG=&@H)&$I"B`@("`@("`@?2!G<F5P('L*
M("`@("`@("`@("`@(2]"4T1004XO"B`@("`@("`@?2!G<F5P('L*("`@("`@
M("`@("`@*"1B=6YD;&4@;F4@)W-I=&4G*2!O<@H@("`@("`@("`@("`H)%\@
M;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`H@("`@("`@("`@
M("`@)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*("`@("`@
M("!]($!)3D,["@H@("`@("`@(&EF("@D0V]N9FEG>U]D96QI;7T@97$@)UQ<
M)RD@>R!S>UQ<?7LO?6<@9F]R($!I;F,@?0H*("`@("`@("!M>2`E9FEL97,[
M"B`@("`@("`@+UY?/"@N*RDD+R!A;F0@)&9I;&5S>R0Q?2LK(&9O<B!K97ES
M("4Z.CL*("`@("`@("`D9FEL97-[)%]]*RL@9F]R('9A;'5E<R`E24Y#.PH*
M("`@("`@("!M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT
M?3L*("`@("`@("!M>2`E=W)I='1E;CL*"B`@("`@("`@9F]R96%C:"`H<V]R
M="!K97ES("5F:6QE<RD@>PH@("`@("`@("`@("!M>2`H)&YA;64L("1F:6QE
M*3L*"B`@("`@("`@("`@(&9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PH@("`@
M("`@("`@("`@("`@:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD7WTI('L*("`@("`@("`@("`@("`@("`@("`D9FEL92`]("1?.PH@("`@
M("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!E;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I
M*2!["B`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)#$L
M("0R*3L*("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@96QS:68@*&TA7B]L;V%D97(O6UXO72LO
M*"XJ6UY#8UTI7%HA*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&UY("1R
M968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("`@("`@96QS:68@*"UF("(D9&ER+R0Q
M(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]
M("@B)&1I<B\D,2(L("0Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@;&%S
M=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@('T*"B`@("`@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN960@
M)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*("`@("`@("`@("`@
M;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X
M=%Q%)"\["B`@("`@("`@("`@(&]U=',H(&IO:6X@(B(L"B`@("`@("`@("`@
M("`@("!Q<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65]
M(#H@)&9I;&4L"B`@("`@("`@("`@("`@("!Q<2@B+BXN*0H@("`@("`@("`@
M("`I.PH*("`@("`@("`@("`@;7D@)&-O;G1E;G0["B`@("`@("`@("`@(&EF
M("AR968H)&9I;&4I*2!["B`@("`@("`@("`@("`@("`D8V]N=&5N="`]("1F
M:6QE+3Y[8G5F?3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*
M("`@("`@("`@("`@("`@(&]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@
M(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*("`@("`@("`@("`@("`@(&)I;FUO
M9&4H1DE,12D["B`@("`@("`@("`@("`@("`D8V]N=&5N="`](#Q&24Q%/CL*
M("`@("`@("`@("`@("`@(&-L;W-E($9)3$4["@H@("`@("`@("`@("`@("`@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@
M)&9I;&4I"B`@("`@("`@("`@("`@("`@("`@:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PH*("`@("`@
M("`@("`@("`@(",@1&\@;F]T(&QE="!84TQO861E<B!P:6-K('5P(&%U=&\O
M*B!F<F]M(&5N=FER;VYM96YT"B`@("`@("`@("`@("`@("`D8V]N=&5N="`]
M?B!S+V=O=&\@*W)E=')Y("MU;FQE<W,@*RXJ+V=O=&\@<F5T<GD[+PH@("`@
M("`@("`@("`@("`@("`@(&EF(&QC*"1N86UE*2!E<2!L8R@B6%-,;V%D97(N
M<&TB*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;W5T<RAQ<2A7<FET
M=&5N(&%S("(D;F%M92(I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@B1DE,
M12(I.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H
M)&YA;64I("L@.2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'-P<FEN=&8H
M"B`@("`@("`@("`@("`@("`B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M
M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64*("`@("`@("`@("`@*2D["B`@
M("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N
M="DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@D8V]N=&5N="D["B`@("`@
M("`@?0H@("`@?0H@("`@(R!]?7T*"B`@("`C($YO=R!W<FET92!O=70@=&AE
M(%!!4B!A;F0@;6%G:6,@<W1R:6YG<R![>WL*("`@("1Z:7`M/G=R:71E5&]&
M:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*"B`@("`D8V%C:&5?;F%M92`]('-U
M8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["B`@("!I9B`H(21C86-H95]N86UE
M(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*("`@("`@("!M
M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ
M4TA!+3YN97<H,2D@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$
M:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN
M97<@?3L*"B`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T
M.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@(&UY("1S:&%?=F5R<VEO;B`]
M(&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@
M(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E
M<2`G-2XS.2<I('L*("`@("`@("`@("`@)&-T>"T^861D9FEL92@D;W5T+"`B
M8B(I(&EF("@D8W1X*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@
M("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*
M("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@
M("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@(&-L;W-E*"1F
M:"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1C86-H95]N
M86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*("`@('T*
M("`@("1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE
M7VYA;64I.PH@("`@)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*("`@("1F:"T^
M<')I;G0H)&-A8VAE7VYA;64I.PH@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@
M)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B`@("`D9F@M/G!R:6YT
M*")<;E!!4BYP;5QN(BD["B`@("`D9F@M/F-L;W-E.PH@("`@8VAM;V0@,#<U
M-2P@)&]U=#L*("`@(",@?7U]"@H@("`@97AI=#L*?0HC('U]?0H*(R!0<F5P
M87)E("1P<F]G;F%M92!I;G1O(%!!4B!F:6QE(&-A8VAE('M[>PI["B`@("!L
M87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["@H@("`@7V9I>%]P<F]G
M;F%M92@I.PH*("`@(",@3F]W(&QO860@=&AE(%!!4B!F:6QE(&%N9"!P=70@
M:70@:6YT;R!005(Z.DQI8D-A8VAE('M[>PH@("`@<F5Q=6ER92!005(["B`@
M("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H*("`@('L*("`@
M("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@
M;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@1FEL93HZ1FEN9#L*("`@
M("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*("`@(&UY("1Z:7`@
M/2!!<F-H:79E.CI::7`M/FYE=SL*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN
M97<["B`@("`D9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@
M(B0A.B`D0"(["B`@("`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D
M<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A
M.B`D0"(["@H@("`@<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*("`@("10
M05(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PH*("`@("1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["B`@("!O=71S*'%Q*%PD14Y6>U!!4E]414U0
M?2`]("(D14Y6>U!!4E]414U0?2(I*3L*"B`@("!I9B`H9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*
M("`@("`@("!F;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@
M>PH@("`@("`@("`@("!N97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PH@
M("`@("`@("`@("!M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M
M93L*("`@("`@("`@("`@;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U[
M"B`@("`@("`@("`@("`@("!>"B`@("`@("`@("`@("`@("`O/W-H;&EB+PH@
M("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_
M"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]
M+RD_"B`@("`@("`@("`@("`@("`H6UXO72LI"B`@("`@("`@("`@("`@("`D
M"B`@("`@("`@("`@('UX.PH@("`@("`@("`@("!M>2`D97AT<F%C=%]N86UE
M(#T@)#$["B`@("`@("`@("`@(&UY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C
M+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*("`@
M("`@("`@("`@)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA
M;64I.PH@("`@("`@("`@("!O=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?
M;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B`@("`@("`@?0H@("`@?0H@("`@
M(R!]?7T*?0HC('U]?0H*(R!)9B!T:&5R92=S(&YO(&UA:6XN<&P@=&\@<G5N
M+"!S:&]W('5S86=E('M[>PIU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97TI('L*("`@(&1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@
M)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C
M+G!A<B!=(%L@<')O9W)A;2YP;"!="B`@("`@("`D,"!;("U"?"UB(%T@6RU/
M;W5T9FEL95T@<W)C+G!A<@HN"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0HC('U]?0H*<W5B($-R
M96%T95!A=&@@>PH@("`@;7D@*"1N86UE*2`]($!?.PH@("`@"B`@("!R97%U
M:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@;7D@*"1B87-E;F%M92P@)'!A=&@L
M("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<
M+BXJ)RDI.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.E!A=&@["B`@("`*("`@
M($9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@
M(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*"G-U8B!R97%U:7)E7VUO9'5L
M97,@>PH@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@
M)%Y/(&YE("=-4U=I;C,R)SL*"B`@("!R97%U:7)E(&QI8CL*("`@(')E<75I
M<F4@1'EN84QO861E<CL*("`@(')E<75I<F4@:6YT96=E<CL*("`@(')E<75I
M<F4@<W1R:6-T.PH@("`@<F5Q=6ER92!W87)N:6YG<SL*("`@(')E<75I<F4@
M=F%R<SL*("`@(')E<75I<F4@0V%R<#L*("`@(')E<75I<F4@0V%R<#HZ2&5A
M=GD["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(')E<75I<F4@
M17AP;W)T97(["B`@("!R97%U:7)E($9C;G1L.PH@("`@<F5Q=6ER92!&:6QE
M.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@<F5Q=6ER92!8
M4TQO861E<CL*("`@(')E<75I<F4@0V]N9FEG.PH@("`@<F5Q=6ER92!)3SHZ
M2&%N9&QE.PH@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@(')E<75I<F4@0V]M
M<')E<W,Z.EIL:6(["B`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@(')E
M<75I<F4@4$%2.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER
M92!005(Z.D1I<W0["B`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*("`@(&5V86P@>R!R97%U:7)E($-W9"!].PH@("`@979A;"![(')E<75I
M<F4@5VEN,S(@?3L*("`@(&5V86P@>R!R97%U:7)E(%=I;C,R.CI0<F]C97-S
M('T["B`@("!E=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*("`@(&5V
M86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PI]"@HC(%1H
M92!#('9E<G-I;VX@;V8@=&AI<R!C;V1E(&%P<&5A<G,@:6X@;7EL9'(O;6MT
M;7!D:7(N8PIS=6(@7W-E=%]P87)?=&5M<"!["B`@("!I9B`H)$5.5GM005)?
M5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PH@("`@("`@
M("1P87)?=&5M<"`]("0Q.PH@("`@("`@(')E='5R;CL*("`@('T*"B`@("!F
M;W)E86-H(&UY("1P871H("@*("`@("`@("`H;6%P("1%3E9[)%]]+"!Q=R@@
M4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*("`@("`@
M("!Q=R@@0SI<7%1%35`@+W1M<"`N("D*("`@("D@>PH@("`@("`@(&YE>'0@
M=6YL97-S("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["B`@("`@
M("`@;7D@)'5S97)N86UE.PH@("`@("`@(&UY("1P=W5I9#L*("`@("`@("`C
M(&1O97,@;F]T('=O<FL@979E<GEW:&5R93H*("`@("`@("!E=F%L('LH)'!W
M=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["@H@("`@("`@
M(&EF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B`@("`@("`@
M("`@("1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PH@("`@("`@('T*
M("`@("`@("!E;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*("`@("`@("`@("`@
M)'5S97)N86UE(#T@)'!W=6ED.PH@("`@("`@('T*("`@("`@("!E;'-E('L*
M("`@("`@("`@("`@)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.
M5GM54T52?2!\?"`G4UE35$5-)SL*("`@("`@("!]"B`@("`@("`@)'5S97)N
M86UE(#U^(',O7%<O7R]G.PH*("`@("`@("!M>2`D<W1M<&1I<B`]("(D<&%T
M:"1#;VYF:6=[7V1E;&EM?7!A<BTD=7-E<FYA;64B.PH@("`@("`@(&UK9&ER
M("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&EF("@A)$5.5GM005)?0TQ%04Y]
M(&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PH@("`@
M("`@("`@("!O<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*("`@("`@
M("`@("`@<V5E:R`D9F@L("TQ."P@,CL*("`@("`@("`@("`@<WES<F5A9"`D
M9F@L(&UY("1B=68L(#8["B`@("`@("`@("`@(&EF("@D8G5F(&5Q(")<,$-!
M0TA%(BD@>PH@("`@("`@("`@("`@("`@<V5E:R`D9F@L("TU."P@,CL*("`@
M("`@("`@("`@("`@('-Y<W)E860@)&9H+"`D8G5F+"`T,3L*("`@("`@("`@
M("`@("`@("1B=68@/7X@<R]<,"\O9SL*("`@("`@("`@("`@("`@("1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&UY
M("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI3
M2$$M/FYE=R@Q*2!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E
M<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@
M("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[
M($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@("`@("`@("`C(%=O<FMA
M<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@
M("`@("`@("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S
M=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("`@("`@("`@(&EF("@D
M<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS
M.2<I('L*("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1P<F]G
M;F%M92P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&-T
M>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@
M("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("`@
M("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D
M0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG
M97-T(#H@)&UT:6UE("D["B`@("`@("`@("`@('T*("`@("`@("`@("`@8VQO
M<V4H)&9H*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@
M("1%3E9[4$%27T-,14%.?2`](#$["B`@("`@("`@("`@("1S=&UP9&ER("X]
M("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*("`@("`@("!]"@H@("`@("`@
M("1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["B`@("`@("`@;6MD:7(@)'-T
M;7!D:7(L(#`W-34["B`@("`@("`@;&%S=#L*("`@('T*"B`@("`D<&%R7W1E
M;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@
M/7X@+R@N*RDO.PI]"@IS=6(@7W1E;7!F:6QE('L*("`@(&UY("@D97AT+"`D
M8W)C*2`]($!?.PH@("`@;7D@*"1F:"P@)&9I;&5N86UE*3L*"B`@("`D9FEL
M96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*"B`@("!I9B`H)$5.5GM0
M05)?0TQ%04Y]*2!["B`@("`@("`@=6YL:6YK("1F:6QE;F%M92!I9B`M92`D
M9FEL96YA;64["B`@("`@("`@<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PH@
M("`@?0H@("`@96QS92!["B`@("`@("`@<F5T=7)N("AU;F1E9BP@)&9I;&5N
M86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*("`@('T*"B`@("!O<&5N("1F:"P@
M)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH@
M("`@<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0H*<W5B(%]S971?<')O9VYA
M;64@>PH@("`@:68@*"1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?
M4%)/1TY!345](#U^("\H+BLI+RD@>PH@("`@("`@("1P<F]G;F%M92`]("0Q
M.PH@("`@?0H*("`@("1P<F]G;F%M92!\?#T@)#`["@H@("`@:68@*"1%3E9[
M4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]
M*2`^/2`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M
M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PH@
M("`@?0H*("`@(&EF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["B`@("`@("`@:68@
M*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PH@("`@("`@("`@("!R
M971U<FX@:68@+7,@)&9H.PH@("`@("`@('T*("`@("`@("!I9B`H+7,@(B1P
M<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B`@("`@("`@("`@("1P<F]G;F%M
M92`N/2`D0V]N9FEG>U]E>&5].PH@("`@("`@("`@("!R971U<FX["B`@("`@
M("`@?0H@("`@?0H*("`@(&9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O
M;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*("`@("`@("!N97AT
M(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!
M4E]414U0?3L*("`@("`@("`D9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<
M120O+SL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0H@("`@("`@("`@
M("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[
M7V5X97TB.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64B*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0I]"@IS=6(@7V9I
M>%]P<F]G;F%M92!["B`@("`D,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?
M4%)/1TY!345].PH@("`@:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?
M9&5L:6U]*2`\(#`I('L*("`@("`@("`D<')O9VYA;64@/2`B+B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M92(["B`@("!]"@H@("`@(R!86%@@+2!H86-K('1O
M(&UA:V4@4%=$('=O<FL*("`@(&UY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG
M971C=V0I(#\@0W=D.CIG971C=V0H*0H@("`@("`@("`@("`@("`@.B`H*&1E
M9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W
M9&`I.PH@("`@8VAO;7`H)'!W9"D["B`@("`D<')O9VYA;64@/7X@<R]>*#\]
M7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]
M+SL*"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*"G-U
M8B!?<&%R7VEN:71?96YV('L*("`@(&EF("@@)$5.5GM005)?24Y)5$E!3$E:
M141]*RL@/3T@,2`I('L*("`@("`@("!R971U<FX["B`@("!](&5L<V4@>PH@
M("`@("`@("1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["B`@("!]"@H@("`@
M9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.
M04U%($%21T,@05)'5E\P("D@*2!["B`@("`@("`@9&5L971E("1%3E9[)U!!
M4E\G+B1??3L*("`@('T*("`@(&9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.
M($1%0E5'("\I('L*("`@("`@("`D14Y6>R=005)?)RXD7WT@/2`D14Y6>R=0
M05)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]].PH@("`@?0H*("`@(&UY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,
M14%.7U\@("`@("`@("`@("`@("`B.PH*("`@(&EF("@D14Y6>U!!4E]414U0
M?2D@>PH@("`@("`@(&1E;&5T92`D14Y6>U!!4E]#3$5!3GT["B`@("!]"B`@
M("!E;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["B`@
M("`@("`@;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N
M9W1H*")#3$5!3B(I*3L*("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`D,2!I
M9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PH@("`@?0I]"@IS=6(@
M;W5T<R!["B`@("!R971U<FX@:68@)'%U:65T.PH@("`@:68@*"1L;V=F:"D@
M>PH@("`@("`@('!R:6YT("1L;V=F:"`B0%]<;B(["B`@("!]"B`@("!E;'-E
M('L*("`@("`@("!P<FEN="`B0%]<;B(["B`@("!]"GT*"G-U8B!I;FET7VEN
M8R!["B`@("!R97%U:7)E($-O;F9I9SL*("`@('!U<V@@0$E.0RP@9W)E<"!D
M969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"B`@("`@("`@
M87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*
M("`@("`@("!V96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`H@("`@*3L*?0H*
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C"B,@5&AE(&UA:6X@<&%C:V%G
M92!F;W(@<V-R:7!T(&5X96-U=&EO;@H*<&%C:V%G92!M86EN.PH*<F5Q=6ER
M92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM
M<&]R="A`<&%R7V%R9W,I.PH*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P
M97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C
M=&]R>5QN*0H@("`@=6YL97-S("UE("1P<F]G;F%M93L*"F1O("1P<F]G;F%M
M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("1`(&EF("1`.PH*?3L*"B0Z.E]?15)23U(@/2`D0"!I9B`D
M0#L*?0H*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%
M6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2
M.PH*,3L*"B-L:6YE(#$P,#D*"E]?14Y$7U\*`````'!A<BYP;````````/__
M___@.D``]#I``/">`````````````(RA``"H0```4)X`````````````T*$`
M``A```!(G@````````````#NH0```$```&">`````````````/*B```80```
M``````````````````````````#>H0```````)BA``"NH0``O*$```````!\
MHP``;*,``%RC``!(HP``/*,``"RC```<HP``%*,```:C``#^H@``YJ(``-RB
M``#.H@``PJ(``+BB``"JH@``BJ,``):B``",H@``?*(``'"B``!FH@``7*(`
M`%*B``!(H@``/J(``"ZB```DH@``&J(``!"B```&H@``_*$``)RC``"PHP``
MH*(```````!XH0``9J$``%"A``!"H0``,*$``!"A``#XH```XJ```-2@``#(
MH```N*```*R@``":H```AJ```'2@``!DH```4*```$"@```PH```(J````Z@
M``#^GP``YI\``-2?``#$GP``M)\``*"?``".GP``>I\``&R?````````X0-0
M97)L7VYE=UA3`````U!E<FQ?9V5T7V-O;G1E>'0``!P%8F]O=%]$>6YA3&]A
M9&5R`&<"4&5R;%]4<W1A=&)U9E]P='(`MP!097)L7TE,24]?<'1R`+H`4&5R
M;%])365M7W!T<@"^`%!E<FQ?25!R;V-?<'1R``#&`E!E<FQ?8W)O86M?;F]C
M;VYT97AT``"U`%!E<FQ?241I<E]P='(`U@!097)L7TEC;VUP8W9?<'1R``"4
M`U!E<FQ?;6=?<V5T`+D$4&5R;%]S=E]S971P=@""`E!E<FQ?879?<VAI9G0`
M:@1097)L7W-V7S)P=E]F;&%G<P![`E!E<FQ?879?9F5T8V@`(@-097)L7V=V
M7V9E=&-H<'8`:P)097)L7U1T86EN=&5D7W!T<@`9!5!E<FQ?=VEN,S)?=&5R
M;0`G!7!E<FQ?9G)E90`F!7!E<FQ?9&5S=')U8W0`*@5P97)L7W)U;@``*05P
M97)L7W!A<G-E```?!%!E<FQ?<V%F97-Y<VUA;&QO8P``]P!097)L7TEE>&ET
M7V9L86=S7W!T<@``8@%097)L7TEP97)L7V1E<W1R=6-T7VQE=F5L7W!T<@`E
M!7!E<FQ?8V]N<W1R=6-T```?!7!E<FQ?86QL;V,``)@`4&5R;%]'9&]?=6YD
M=6UP7W!T<@`8!5!E<FQ?=VEN,S)?:6YI=`#B`U!E<FQ?;F5W6%-?9FQA9W,`
M`'!E<FPU."YD;&P``'4!1V5T36]D=6QE1FEL94YA;65!``#O`$9R965,:6)R
M87)Y`'<!1V5T36]D=6QE2&%N9&QE00``2T523D5,,S(N9&QL```C`4=E=%5S
M97).86UE00``041605!),S(N9&QL``"R`G-P<FEN=&8`N`)S=')C;7```,<"
M<W1R=&]K``"^`G-T<FQE;@``Q0)S=')S='(``&T`7U]P7U]E;G9I<F]N``"8
M`FUE;6UO=F4`P0)S=')N8W!Y`,`"<W1R;F-M<`""`5]M:V1I<@``C@%?<&-T
M>7!E`!4!7VES8W1Y<&4``&$`7U]M8E]C=7)?;6%X``"7`FUE;6-P>0``F0)M
M96US970``)D!7W)M9&ER``#?`%]F:6YD8VQO<V4``-T!7W5N;&EN:P#B`%]F
M:6YD;F5X=`#@`%]F:6YD9FER<W0``+\!7W-T<F1U<`#%`5]S=')N:6-M<`!-
M4U9#4E0N9&QL``#3`%]E>&ET`$@`7UAC<'1&:6QT97(`20)E>&ET``!D`%]?
M<%]?7VEN:71E;G8`6`!?7V=E=&UA:6YA<F=S``\!7VEN:71T97)M`(,`7U]S
M971U<V5R;6%T:&5R<@``G0!?861J=7-T7V9D:78``&H`7U]P7U]C;VUM;V1E
M``!O`%]?<%]?9FUO9&4``($`7U]S971?87!P7W1Y<&4``,H`7V5X8V5P=%]H
M86YD;&5R,P``MP!?8V]N=')O;&9P````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````4$%``$Q!0`#_____S)U``+!9
M```````````````````!````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````#``,````H``"`#@```$@``(`0
M````8```@````````````````````@`!````>```@`(```"0``"`````````
M```````````!`&4```"H``"````````````````````!``$```#```"`````
M```````````````!``````#8```````````````````````!``````#H````
M```````````````````!``````#X```````````````````````!```````(
M`0``F,,``&@%``````````````#)``"H"`````````````"HT0``(@``````
M````````(,$``'0"````````````````````````=`(T````5@!3`%\`5@!%
M`%(`4P!)`$\`3@!?`$D`3@!&`$\``````+T$[_X```$`````````````````
M`````#\````!````!``$``$```````````````````#4`0```0!3`'0`<@!I
M`&X`9P!&`&D`;`!E`$D`;@!F`&\```"P`0```0`P`#0`,``P`#``-`!B`#``
M```8`````0!#`&\`;0!M`&4`;@!T`',````@`````0!#`&\`;0!P`&$`;@!Y
M`$X`80!M`&4``````"@````!`$8`:0!L`&4`1`!E`',`8P!R`&D`<`!T`&D`
M;P!N```````@`````0!&`&D`;`!E`%8`90!R`',`:0!O`&X``````"`````!
M`$D`;@!T`&4`<@!N`&$`;`!.`&$`;0!E````)`````$`3`!E`&<`80!L`$,`
M;P!P`'D`<@!I`&<`:`!T````*`````$`3`!E`&<`80!L`%0`<@!A`&0`90!M
M`&$`<@!K`',``````"@````!`$\`<@!I`&<`:0!N`&$`;`!&`&D`;`!E`&X`
M80!M`&4````@`````0!0`'(`:0!V`&$`=`!E`$(`=0!I`&P`9````"`````!
M`%``<@!O`&0`=0!C`'0`3@!A`&T`90``````)`````$`4`!R`&\`9`!U`&,`
M=`!6`&4`<@!S`&D`;P!N````(`````$`4P!P`&4`8P!I`&$`;`!"`'4`:0!L
M`&0```!$`````0!6`&$`<@!&`&D`;`!E`$D`;@!F`&\``````"0`!````%0`
M<@!A`&X`<P!L`&$`=`!I`&\`;@````````2P!``````H````$````"`````!
M``@````````!```````````````!`````0``!@8&``0$!``"`@(``````$)"
M0@"=G9T`;FYN`(&!@0"QL;$`____`'-S<P"?GY\`6%A8`+*RL@#]_?T`:VMK
M`/S\_`#7U]<`%A86`-K:V@"6EI8`CHZ.`$9&1@#+R\L`"PL+`*"@H`#^_OX`
MR<G)`,'!P0`#`P,`$1$1`).3DP"SL[,`[N[N`/3T]`#CX^,`Y>7E`**BH@"Z
MNKH`KZ^O``<'!P!Q<7$`M;6U`/7U]0")B8D`BHJ*`#0T-`#HZ.@`-34U`%I:
M6@"WM[<`V-C8`-#0T``='1T`#`P,`(^/CP"^OKX`;6UM``D)"0";FYL`+R\O
M`,W-S0#9V=D`&1D9`$U-30!$1$0`4%!0`#P\/`!D9&0`PL+"`#(R,@`("`@`
M#0T-``\/#P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````%!04%!04%!04%!04%!00$!`35`(P5!,4-!041%
M+@$!`0$!`0$%`3P7%P$!$P$!`0$!`0$!%0$!)A4!`0\!`0$!`0$!`1,!$0$%
M-0$F`0$!`0$!`0$B$A`Q#P4!(`$!`0$!`0$!$`H@(A45+B$N`0$!`0$?("$0
M(A`C(R4F)P$!`0$E$!`0$!`0$!`0%T4!`0%!$!`0$!`0$!`0$!`7`0$!#Q`0
M%1`0$!`0$!`0`0$!`1(0$!,?$!`0$!`0!P$!`0$@$!`0`0\0$!`0$0$!`0$!
M!R`0"@$!!1`0$#$!`0$!`0$!`0$!`0%!!0\!`0$!`0$!`0$!`0$!`0$!`0$!
M`0&``0``P`$``.`#``#P`P``\`,``/`#``#@`P``P`$``(`!``"``0``@`,`
M`(`#````!P````<``(X/``#_'P``*````"````!``````0`(````````!```
M`````````````0````$````````!`0$``@("``,#`P`$!`0`!04%``8&!@`'
M!P<`"`@(``D)"0`*"@H`"PL+``P,#``-#0T`#@X.``\/#P`0$!``$1$1`!(2
M$@`3$Q,`%!04`!45%0`6%A8`%Q<7`!@8&``9&1D`&AH:`!L;&P`<'!P`'1T=
M`!X>'@`?'Q\`("`@`"$A(0`B(B(`(R,C`"0D)``E)24`)B8F`"<G)P`H*"@`
M*2DI`"HJ*@`K*RL`+"PL`"TM+0`N+BX`+R\O`#`P,``Q,3$`,C(R`#,S,P`T
M-#0`-34U`#8V-@`W-S<`.#@X`#DY.0`Z.CH`.SL[`#P\/``]/3T`/CX^`#\_
M/P!`0$``04%!`$)"0@!#0T,`1$1$`$5%10!&1D8`1T='`$A(2`!)24D`2DI*
M`$M+2P!,3$P`34U-`$Y.3@!/3T\`4%!0`%%140!24E(`4U-3`%145`!5554`
M5E96`%=75P!86%@`65E9`%I:6@!;6UL`7%Q<`%U=70!>7EX`7U]?`&!@8`!A
M86$`8F)B`&-C8P!D9&0`965E`&9F9@!G9V<`:&AH`&EI:0!J:FH`:VMK`&QL
M;`!M;6T`;FYN`&]O;P!P<'``<7%Q`')R<@!S<W,`='1T`'5U=0!V=G8`=W=W
M`'AX>`!Y>7D`>GIZ`'M[>P!\?'P`?7U]`'Y^?@!_?W\`@("``(&!@0""@H(`
M@X.#`(2$A`"%A84`AH:&`(>'AP"(B(@`B8F)`(J*B@"+BXL`C(R,`(V-C0".
MCHX`CX^/`)"0D`"1D9$`DI*2`).3DP"4E)0`E965`):6E@"7EY<`F)B8`)F9
MF0":FIH`FYN;`)R<G`"=G9T`GIZ>`)^?GP"@H*``H:&A`**BH@"CHZ,`I*2D
M`*6EI0"FIJ8`IZ>G`*BHJ`"IJ:D`JJJJ`*NKJP"LK*P`K:VM`*ZNK@"OKZ\`
ML+"P`+&QL0"RLK(`L[.S`+2TM`"UM;4`MK:V`+>WMP"XN+@`N;FY`+JZN@"[
MN[L`O+R\`+V]O0"^OKX`O[^_`,#`P`#!P<$`PL+"`,/#PP#$Q,0`Q<7%`,;&
MQ@#'Q\<`R,C(`,G)R0#*RLH`R\O+`,S,S`#-S<T`SL[.`,_/SP#0T-``T='1
M`-+2T@#3T],`U-34`-75U0#6UM8`U]?7`-C8V`#9V=D`VMK:`-O;VP#<W-P`
MW=W=`-[>W@#?W]\`X.#@`.'AX0#BXN(`X^/C`.3DY`#EY>4`YN;F`.?GYP#H
MZ.@`Z>GI`.KJZ@#KZ^L`[.SL`.WM[0#N[NX`[^_O`/#P\`#Q\?$`\O+R`//S
M\P#T]/0`]?7U`/;V]@#W]_<`^/CX`/GY^0#Z^OH`^_O[`/S\_`#]_?T`_O[^
M`/___P`T-#0\/#P\/#P\/#P\/#P\/#P\/#P\/#PL#`0$!`0$!%RTU-34U-34
MU-34U-S4U-34U-34U-34U+0T400$!`0$9,SL]/3T_/3\]/3T_/3\]/ST_/S\
M]/3LQ#11400$!`1DQ.3L]/3T]/3T]/3T]/3T]/3T]/3T[.R\-%%1400$!&3$
MY.SL[.3L[.SDY.3D[.SD[.3L[.SLY+PT45%1400$9+SD[.RLC*S4Q)24G)2,
MC)24E)R<G.S<O#1145%1401DO-SD[.3$492L9.2D3#0L7,3,4;34Y-R\-%%1
M45%1462\W.3D[.3D481TY(QLI)QLC+QTK-3DW+PT!`0$!`0$9+S<Y.3LY.2\
M48S4U(RLS'3,W*11Q.3<O#0$!`0$!`1DO-SDY.3DY-R,?)RT?(2<;,SDO'3$
MY-RT-`0$!`0$!%R\W-SDY.3DU)RD7)2,S#R49,R\C%'<U+0T!`0$!`0$9+34
MW-S<Y-R,C*PLO+3,6L1DG&R4I-S4M#0$!`0$!`1<M-3<W.3<W'24U$RD](P\
MU'24=)Q,W,RT-`0$!`0$!&2TU-S<W.3<=%'T=(3LS&3D?&RDM&RDU+0T!`0$
M!`0$9+3,W-S,?(R$M/S,Q/STM/R\9,RLA%&\K#0$!`0$!`1<M,S4S(RDW-SL
M_/S\_/ST_.RT[*Q\E%&L-`0$!`0$!%RLS,QLG/3\_/S\_/S\_/S\_/S\Q)2,
M4:PT!`0$!`0$7*S$O'SD_/S\_/S\_/S\_/S\_/SLS*Q1K#0$!`0$!`1<K+1,
MQ/S\_.ST_/S\_/S\_/S\_/2\4<2L-`0$!`0$!%RLM$S4_/STM-S\_/S\_/S\
M_/S\S%',Q*0T!`0$!`0$7*S$I%'\_/RTG/3\_/S\_/S\_/244<S$I"P$!`0$
M!`1<I*11A.S\_,QDM.S\_/S\_/S\U&RLS+RD-`0$!`0$!%RD9'2\]/S\Q%&$
MG.3\_/S\_.2,4<S,Q*0T!`0$!`0$7*1LC.3T_/R<4<Q1E.S\_/S\O'3,S,2\
MG"P$!`0$!`1<I*QD7&2DI%&LS,1TE.3T_.11O,S,Q+R<-`0$!`0$!%RDM+R\
MC%%1Q,3,S*Q1?'R4;'R\S,3$O)PL!`0$!`0$7)R\Q,3$Q,3$Q,3$Q,1145%1
MO,3$Q,2TG#0$!`0$!`14G+3$Q,3$Q,3$Q,3$Q,3$Q,3$Q,3$O+2<+`0$!`0$
M!%2<O,3$O+R\O+R\O+R\O+R\O+R\O+R\M)PL!`0$!`0$7)RTQ+RTM+2TM+2T
MM+2TM+2TM+2TM+2LG"P$!`0$!`14A)2<G)24E)24E)24E)24E)24E)24E)2$
M)`0$!`0$!$147%Q<7%Q<7%Q<7%Q<7%Q<7%Q<7%Q<7%0T!`0$!`0$````/P``
M`!\````/````!P````,````!`````````#\````_````/P```#\````_````
M/P```#\````_````/P```#\````_````/P```#\````_````/P```#\````_
M````/P```#\````_````/P```#\````_````/P```#\```$``@`0$````0`(
M`&@%```!`"`@```!``@`J`@```(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!.0C$P`````'BO:T<!````0SI<4&5R;%QB=6EL9%Q0
>05(M4&%C:V5R+3`N.3<W7&UY;&1R7'!A<BYP9&(`
